import os
import os.path
import re
import sys

from django import template

register = template.Library()

PATTERN = re.compile(r'page=(\d+)')

def _calc_page(value, func):
    t = PATTERN.search(value)
    if t is None:
        if '?' in value:
            return value + '&page=2'
        return value + '?&page=2'
    m = t.group()
    num = int(m.split('=')[1])
    return value.replace(m, '&page=%d' % func(num))

@register.filter(name='prev_page')
def prev_page(value):
    return _calc_page(value, lambda n: n-1)

@register.filter(name='next_page')
def next_page(value):
    return _calc_page(value, lambda n: n+1)

@register.filter(name='range')
def _range(min=1,max=5):
    return range(min,max+1)

@register.filter(name='get_highlight')
def get_highlight(photo, request):
    if not photo.private or request.user.is_authenticated:
        return photo
    for p in photo.the_album.get_photos():
        if not p.private:
            return p
    message = _('This should not be possible: %(photo)s' % { 'photo': photo })
    raise ValueError(message)

@register.filter(name='get_the_path')
def get_the_path(photo, results):
    if results:
        return photo.url[1:]
    return photo.basename
